@@ -212,7 +212,8 @@ module Aws
       def defaults
         @defaults ||= begin
           path = File.expand_path('../../partitions.json', __FILE__)
-          JSON.load(File.read(path))
+          defaults = JSON.parse(File.read(path), freeze: true)
+          defaults.merge('partitions' => defaults['partitions'].dup)
         end
       end
 
@@ -227,26 +228,45 @@ module Aws
             'ACMPCA' => 'acm-pca',
             'APIGateway' => 'apigateway',
             'AccessAnalyzer' => 'access-analyzer',
+            'Account' => 'account',
             'AlexaForBusiness' => 'a4b',
             'Amplify' => 'amplify',
+            'AmplifyBackend' => 'amplifybackend',
+            'AmplifyUIBuilder' => 'amplifyuibuilder',
             'ApiGatewayManagementApi' => 'execute-api',
             'ApiGatewayV2' => 'apigateway',
             'AppConfig' => 'appconfig',
+            'AppConfigData' => 'appconfigdata',
+            'AppIntegrationsService' => 'app-integrations',
             'AppMesh' => 'appmesh',
+            'AppRegistry' => 'servicecatalog-appregistry',
+            'AppRunner' => 'apprunner',
             'AppStream' => 'appstream2',
             'AppSync' => 'appsync',
+            'Appflow' => 'appflow',
             'ApplicationAutoScaling' => 'application-autoscaling',
+            'ApplicationCostProfiler' => 'application-cost-profiler',
             'ApplicationDiscoveryService' => 'discovery',
             'ApplicationInsights' => 'applicationinsights',
             'Athena' => 'athena',
+            'AuditManager' => 'auditmanager',
             'AugmentedAIRuntime' => 'a2i-runtime.sagemaker',
             'AutoScaling' => 'autoscaling',
             'AutoScalingPlans' => 'autoscaling-plans',
             'Backup' => 'backup',
+            'BackupGateway' => 'backup-gateway',
+            'BackupStorage' => 'backupstorage',
             'Batch' => 'batch',
+            'BillingConductor' => 'billingconductor',
+            'Braket' => 'braket',
             'Budgets' => 'budgets',
             'Chime' => 'chime',
+            'ChimeSDKIdentity' => 'identity-chime',
+            'ChimeSDKMediaPipelines' => 'media-pipelines-chime',
+            'ChimeSDKMeetings' => 'meetings-chime',
+            'ChimeSDKMessaging' => 'messaging-chime',
             'Cloud9' => 'cloud9',
+            'CloudControlApi' => 'cloudcontrolapi',
             'CloudDirectory' => 'clouddirectory',
             'CloudFormation' => 'cloudformation',
             'CloudFront' => 'cloudfront',
@@ -256,7 +276,9 @@ module Aws
             'CloudTrail' => 'cloudtrail',
             'CloudWatch' => 'monitoring',
             'CloudWatchEvents' => 'events',
+            'CloudWatchEvidently' => 'evidently',
             'CloudWatchLogs' => 'logs',
+            'CloudWatchRUM' => 'rum',
             'CodeArtifact' => 'codeartifact',
             'CodeBuild' => 'codebuild',
             'CodeCommit' => 'codecommit',
@@ -275,9 +297,13 @@ module Aws
             'ComputeOptimizer' => 'compute-optimizer',
             'ConfigService' => 'config',
             'Connect' => 'connect',
+            'ConnectCampaignService' => 'connect-campaigns',
+            'ConnectContactLens' => 'contact-lens',
             'ConnectParticipant' => 'participant.connect',
+            'ConnectWisdomService' => 'wisdom',
             'CostExplorer' => 'ce',
             'CostandUsageReportService' => 'cur',
+            'CustomerProfiles' => 'profile',
             'DAX' => 'dax',
             'DLM' => 'dlm',
             'DataExchange' => 'dataexchange',
@@ -285,20 +311,25 @@ module Aws
             'DataSync' => 'datasync',
             'DatabaseMigrationService' => 'dms',
             'Detective' => 'api.detective',
+            'DevOpsGuru' => 'devops-guru',
             'DeviceFarm' => 'devicefarm',
             'DirectConnect' => 'directconnect',
             'DirectoryService' => 'ds',
             'DocDB' => 'rds',
+            'Drs' => 'drs',
             'DynamoDB' => 'dynamodb',
             'DynamoDBStreams' => 'streams.dynamodb',
             'EBS' => 'ebs',
             'EC2' => 'ec2',
             'EC2InstanceConnect' => 'ec2-instance-connect',
             'ECR' => 'api.ecr',
+            'ECRPublic' => 'api.ecr-public',
             'ECS' => 'ecs',
             'EFS' => 'elasticfilesystem',
             'EKS' => 'eks',
             'EMR' => 'elasticmapreduce',
+            'EMRContainers' => 'emr-containers',
+            'EMRServerless' => 'emr-serverless',
             'ElastiCache' => 'elasticache',
             'ElasticBeanstalk' => 'elasticbeanstalk',
             'ElasticInference' => 'api.elastic-inference',
@@ -307,39 +338,55 @@ module Aws
             'ElasticTranscoder' => 'elastictranscoder',
             'ElasticsearchService' => 'es',
             'EventBridge' => 'events',
+            'FIS' => 'fis',
             'FMS' => 'fms',
             'FSx' => 'fsx',
+            'FinSpaceData' => 'finspace-api',
+            'Finspace' => 'finspace',
             'Firehose' => 'firehose',
             'ForecastQueryService' => 'forecastquery',
             'ForecastService' => 'forecast',
             'FraudDetector' => 'frauddetector',
             'GameLift' => 'gamelift',
+            'GameSparks' => 'gamesparks',
             'Glacier' => 'glacier',
             'GlobalAccelerator' => 'globalaccelerator',
             'Glue' => 'glue',
+            'GlueDataBrew' => 'databrew',
             'Greengrass' => 'greengrass',
+            'GreengrassV2' => 'greengrass',
             'GroundStation' => 'groundstation',
             'GuardDuty' => 'guardduty',
             'Health' => 'health',
+            'HealthLake' => 'healthlake',
             'Honeycode' => 'honeycode',
             'IAM' => 'iam',
             'IVS' => 'ivs',
+            'IdentityStore' => 'identitystore',
             'Imagebuilder' => 'imagebuilder',
             'ImportExport' => 'importexport',
             'Inspector' => 'inspector',
+            'Inspector2' => 'inspector2',
             'IoT' => 'iot',
             'IoT1ClickDevicesService' => 'devices.iot1click',
             'IoT1ClickProjects' => 'projects.iot1click',
             'IoTAnalytics' => 'iotanalytics',
+            'IoTDeviceAdvisor' => 'api.iotdeviceadvisor',
             'IoTEvents' => 'iotevents',
             'IoTEventsData' => 'data.iotevents',
+            'IoTFleetHub' => 'api.fleethub.iot',
             'IoTJobsDataPlane' => 'data.jobs.iot',
             'IoTSecureTunneling' => 'api.tunneling.iot',
             'IoTSiteWise' => 'iotsitewise',
             'IoTThingsGraph' => 'iotthingsgraph',
+            'IoTTwinMaker' => 'iottwinmaker',
+            'IoTWireless' => 'api.iotwireless',
+            'Ivschat' => 'ivschat',
             'KMS' => 'kms',
             'Kafka' => 'kafka',
+            'KafkaConnect' => 'kafkaconnect',
             'Kendra' => 'kendra',
+            'Keyspaces' => 'cassandra',
             'Kinesis' => 'kinesis',
             'KinesisAnalytics' => 'kinesisanalytics',
             'KinesisAnalyticsV2' => 'kinesisanalytics',
@@ -352,14 +399,24 @@ module Aws
             'LambdaPreview' => 'lambda',
             'Lex' => 'runtime.lex',
             'LexModelBuildingService' => 'models.lex',
+            'LexModelsV2' => 'models-v2-lex',
+            'LexRuntimeV2' => 'runtime-v2-lex',
             'LicenseManager' => 'license-manager',
+            'LicenseManagerUserSubscriptions' => 'license-manager-user-subscriptions',
             'Lightsail' => 'lightsail',
+            'LocationService' => 'geo',
+            'LookoutEquipment' => 'lookoutequipment',
+            'LookoutMetrics' => 'lookoutmetrics',
+            'LookoutforVision' => 'lookoutvision',
             'MQ' => 'mq',
             'MTurk' => 'mturk-requester',
+            'MWAA' => 'airflow',
             'MachineLearning' => 'machinelearning',
             'Macie' => 'macie',
             'Macie2' => 'macie2',
+            'MainframeModernization' => 'm2',
             'ManagedBlockchain' => 'managedblockchain',
+            'ManagedGrafana' => 'grafana',
             'MarketplaceCatalog' => 'catalog.marketplace',
             'MarketplaceCommerceAnalytics' => 'marketplacecommerceanalytics',
             'MarketplaceEntitlementService' => 'entitlement.marketplace',
@@ -372,52 +429,78 @@ module Aws
             'MediaStore' => 'mediastore',
             'MediaStoreData' => 'data.mediastore',
             'MediaTailor' => 'api.mediatailor',
+            'MemoryDB' => 'memory-db',
+            'Mgn' => 'mgn',
             'MigrationHub' => 'mgh',
             'MigrationHubConfig' => 'migrationhub-config',
+            'MigrationHubRefactorSpaces' => 'refactor-spaces',
+            'MigrationHubStrategyRecommendations' => 'migrationhub-strategy',
             'Mobile' => 'mobile',
             'Neptune' => 'rds',
+            'NetworkFirewall' => 'network-firewall',
             'NetworkManager' => 'networkmanager',
+            'NimbleStudio' => 'nimble',
+            'OpenSearchService' => 'es',
             'OpsWorks' => 'opsworks',
             'OpsWorksCM' => 'opsworks-cm',
             'Organizations' => 'organizations',
             'Outposts' => 'outposts',
             'PI' => 'pi',
+            'Panorama' => 'panorama',
             'Personalize' => 'personalize',
             'PersonalizeEvents' => 'personalize-events',
             'PersonalizeRuntime' => 'personalize-runtime',
             'Pinpoint' => 'pinpoint',
             'PinpointEmail' => 'email',
             'PinpointSMSVoice' => 'sms-voice.pinpoint',
+            'PinpointSMSVoiceV2' => 'sms-voice',
             'Polly' => 'polly',
             'Pricing' => 'api.pricing',
+            'PrivateNetworks' => 'private-networks',
+            'PrometheusService' => 'aps',
+            'Proton' => 'proton',
             'QLDB' => 'qldb',
             'QLDBSession' => 'session.qldb',
             'QuickSight' => 'quicksight',
             'RAM' => 'ram',
             'RDS' => 'rds',
             'RDSDataService' => 'rds-data',
+            'RecycleBin' => 'rbin',
             'Redshift' => 'redshift',
+            'RedshiftDataAPIService' => 'redshift-data',
+            'RedshiftServerless' => 'redshift-serverless',
             'Rekognition' => 'rekognition',
+            'ResilienceHub' => 'resiliencehub',
             'ResourceGroups' => 'resource-groups',
             'ResourceGroupsTaggingAPI' => 'tagging',
             'RoboMaker' => 'robomaker',
+            'RolesAnywhere' => 'rolesanywhere',
             'Route53' => 'route53',
             'Route53Domains' => 'route53domains',
+            'Route53RecoveryCluster' => 'route53-recovery-cluster',
+            'Route53RecoveryControlConfig' => 'route53-recovery-control-config',
+            'Route53RecoveryReadiness' => 'route53-recovery-readiness',
             'Route53Resolver' => 'route53resolver',
             'S3' => 's3',
             'S3Control' => 's3-control',
+            'S3Outposts' => 's3-outposts',
             'SES' => 'email',
             'SESV2' => 'email',
             'SMS' => 'sms',
             'SNS' => 'sns',
             'SQS' => 'sqs',
             'SSM' => 'ssm',
+            'SSMContacts' => 'ssm-contacts',
+            'SSMIncidents' => 'ssm-incidents',
             'SSO' => 'portal.sso',
+            'SSOAdmin' => 'sso',
             'SSOOIDC' => 'oidc',
             'STS' => 'sts',
             'SWF' => 'swf',
             'SageMaker' => 'api.sagemaker',
+            'SageMakerFeatureStoreRuntime' => 'featurestore-runtime.sagemaker',
             'SageMakerRuntime' => 'runtime.sagemaker',
+            'SagemakerEdgeManager' => 'edge.sagemaker',
             'SavingsPlans' => 'savingsplans',
             'Schemas' => 'schemas',
             'SecretsManager' => 'secretsmanager',
@@ -429,24 +512,30 @@ module Aws
             'Shield' => 'shield',
             'Signer' => 'signer',
             'SimpleDB' => 'sdb',
+            'SnowDeviceManagement' => 'snow-device-management',
             'Snowball' => 'snowball',
             'States' => 'states',
             'StorageGateway' => 'storagegateway',
             'Support' => 'support',
             'Synthetics' => 'synthetics',
             'Textract' => 'textract',
+            'TimestreamQuery' => 'query.timestream',
+            'TimestreamWrite' => 'ingest.timestream',
             'TranscribeService' => 'transcribe',
             'TranscribeStreamingService' => 'transcribestreaming',
             'Transfer' => 'transfer',
             'Translate' => 'translate',
+            'VoiceID' => 'voiceid',
             'WAF' => 'waf',
             'WAFRegional' => 'waf-regional',
             'WAFV2' => 'wafv2',
+            'WellArchitected' => 'wellarchitected',
             'WorkDocs' => 'workdocs',
             'WorkLink' => 'worklink',
             'WorkMail' => 'workmail',
             'WorkMailMessageFlow' => 'workmailmessageflow',
             'WorkSpaces' => 'workspaces',
+            'WorkSpacesWeb' => 'workspaces-web',
             'XRay' => 'xray',
           }
           # end service ids
